Documentation
¶
Overview ¶
MIT License
Copyright (c) 2025 OcomSoft ¶
Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CamelToSnake ¶
CamelToSnake converts CamelCase to snake_case
func SnakeToCamel ¶
SnakeToCamel converts snake_case to CamelCase
Types ¶
type ForeignKeyTypeResolver ¶
type ForeignKeyTypeResolver struct {
// UUIDType is the SQL type to use for UUID foreign keys (e.g., "UUID" for PostgreSQL, "CHAR(36)" for MySQL)
UUIDType string
// IntegerType is the SQL type to use for integer foreign keys (e.g., "INTEGER" for PostgreSQL, "INT" for MySQL)
IntegerType string
// BigIntType is the SQL type to use for bigint foreign keys
BigIntType string
// SerialType is the SQL type to use for serial/auto-increment foreign keys
SerialType string
}
ForeignKeyTypeResolver helps resolve the appropriate SQL type for foreign key fields by looking up the referenced table's primary key type
func (*ForeignKeyTypeResolver) GetForeignKeyType ¶
func (r *ForeignKeyTypeResolver) GetForeignKeyType(schema *types.Schema, referencedTableName string) string
GetForeignKeyType determines the appropriate SQL type for a foreign key field by looking up the referenced table's primary key type
func (*ForeignKeyTypeResolver) GetForeignKeyTypeFromPrimaryKey ¶
func (r *ForeignKeyTypeResolver) GetForeignKeyTypeFromPrimaryKey(pkField *types.Field) string
GetForeignKeyTypeFromPrimaryKey returns the appropriate foreign key type for a primary key field